route53
    * ``auth_access_key`` Specify access_key for authentication

    * ``auth_access_secret`` Specify access_secret for authentication

    * ``private_zone`` Indicates what kind of hosted zone to use. if true, use only private zones. if false, use only public zones

    * ``zone_id`` The aws hostedzone id to use; e.g. 'a1b2zabcdefghi'

    * ``auth_username`` Alternative way to specify the access_key for authentication

    * ``auth_token`` Alternative way to specify the access_secret for authentication
